@@ -1,14 +1,18 @@
 import glob
 import hashlib
 import os
+import sys
 import tarfile
 from io import BytesIO
 
 import numpy as np
 
+
 pytorch_str = "pytorch"
-mxnet_str =  "mxnet"
+mxnet_str = "mxnet"
 TF_str = "TF"
+TFLITE_str = "TFLITE"
+FILE_str = "FILE"
 
 
 def convert_to_numpy(data):
@@ -29,6 +33,18 @@ def save_model(model, library: str):
             from torch import save
             import dill
             model_path += ".pt"
+            try:
+                # from pytorch_lightning import LightningModule
+                # if isinstance(model, LightningModule):
+                    try:
+                        import cloudpickle
+                        dill = cloudpickle
+                    except ModuleNotFoundError as _:
+                        from ..common import npu_print
+                        npu_print("To use pytorch lightning, please install cloudpickle.", level="ERROR")
+                        sys.exit(1)
+            except ModuleNotFoundError as _:
+                pass
             save(model, model_path, pickle_module=dill)
         elif library == "keras":
             model_path += ".h5"
@@ -74,18 +90,18 @@ def hash_model(model, library):
     if isinstance(model, str):
         with open(model, "rb") as file:
             return hashlib.md5(file.read()).hexdigest()
-    elif library == "pytorch":
+    elif library == pytorch_str:
         hash.update(utf_str(model))
         for p in model.parameters():
             hash.update(utf_str(p))
-    elif library == "mxnet":
+    elif library == mxnet_str:
         from mxnet import sym
         x = sym.var('data')
         x = model(x).tojson()
         hash.update(utf_str(x))
         for param in sorted(model.collect_params().items()):
             hash.update(utf_str(param[1].data()))
-    elif library == "TF":
+    elif library == TF_str:
         try:
             hash.update(utf_str(model.to_json()))
             for param in model.trainable_variables:
